==> dif-database-repository-2.4.2-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IReportManagerService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.dao.ISqlDataSourceDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportTemplateDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportTemplateAreaDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportTemplateAreaTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportTemplateAreaSqlDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportInstanceDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstance;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportInstanceAreaDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceArea;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportInstanceAreaSqlDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.dao.IReportInstanceAreaTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.IJasperReportConfigDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportConfig;
import pt.digitalis.dif.dem.managers.impl.model.dao.IJasperReportLogDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportLog;
import pt.digitalis.dif.dem.managers.impl.model.dao.IJasperReportTemplateDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.dao.IJasperReportTemplateFileDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateFile;
import pt.digitalis.dif.dem.managers.impl.model.dao.IJasperReportTemplateParamDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateParam;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IReportManagerService {

	/**
	 * Obtains a new SqlDataSource DAO
	 *
	 * @return A new ISqlDataSourceDAO
	 */
    public ISqlDataSourceDAO getSqlDataSourceDAO();

    /**
     * Obtains a new DataSet for the SqlDataSource entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<SqlDataSource> getSqlDataSourceDataSet();

	/**
	 * Obtains a new ReportTemplate DAO
	 *
	 * @return A new IReportTemplateDAO
	 */
    public IReportTemplateDAO getReportTemplateDAO();

    /**
     * Obtains a new DataSet for the ReportTemplate entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplate> getReportTemplateDataSet();

	/**
	 * Obtains a new ReportTemplateArea DAO
	 *
	 * @return A new IReportTemplateAreaDAO
	 */
    public IReportTemplateAreaDAO getReportTemplateAreaDAO();

    /**
     * Obtains a new DataSet for the ReportTemplateArea entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplateArea> getReportTemplateAreaDataSet();

	/**
	 * Obtains a new ReportTemplateAreaTrans DAO
	 *
	 * @return A new IReportTemplateAreaTransDAO
	 */
    public IReportTemplateAreaTransDAO getReportTemplateAreaTransDAO();

    /**
     * Obtains a new DataSet for the ReportTemplateAreaTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplateAreaTrans> getReportTemplateAreaTransDataSet();

	/**
	 * Obtains a new ReportTemplateAreaSql DAO
	 *
	 * @return A new IReportTemplateAreaSqlDAO
	 */
    public IReportTemplateAreaSqlDAO getReportTemplateAreaSqlDAO();

    /**
     * Obtains a new DataSet for the ReportTemplateAreaSql entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplateAreaSql> getReportTemplateAreaSqlDataSet();

	/**
	 * Obtains a new ReportInstance DAO
	 *
	 * @return A new IReportInstanceDAO
	 */
    public IReportInstanceDAO getReportInstanceDAO();

    /**
     * Obtains a new DataSet for the ReportInstance entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstance> getReportInstanceDataSet();

	/**
	 * Obtains a new ReportInstanceArea DAO
	 *
	 * @return A new IReportInstanceAreaDAO
	 */
    public IReportInstanceAreaDAO getReportInstanceAreaDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceArea entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceArea> getReportInstanceAreaDataSet();

	/**
	 * Obtains a new ReportInstanceAreaSql DAO
	 *
	 * @return A new IReportInstanceAreaSqlDAO
	 */
    public IReportInstanceAreaSqlDAO getReportInstanceAreaSqlDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceAreaSql entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceAreaSql> getReportInstanceAreaSqlDataSet();

	/**
	 * Obtains a new ReportInstanceAreaTrans DAO
	 *
	 * @return A new IReportInstanceAreaTransDAO
	 */
    public IReportInstanceAreaTransDAO getReportInstanceAreaTransDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceAreaTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceAreaTrans> getReportInstanceAreaTransDataSet();

	/**
	 * Obtains a new JasperReportConfig DAO
	 *
	 * @return A new IJasperReportConfigDAO
	 */
    public IJasperReportConfigDAO getJasperReportConfigDAO();

    /**
     * Obtains a new DataSet for the JasperReportConfig entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportConfig> getJasperReportConfigDataSet();

	/**
	 * Obtains a new JasperReportLog DAO
	 *
	 * @return A new IJasperReportLogDAO
	 */
    public IJasperReportLogDAO getJasperReportLogDAO();

    /**
     * Obtains a new DataSet for the JasperReportLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportLog> getJasperReportLogDataSet();

	/**
	 * Obtains a new JasperReportTemplate DAO
	 *
	 * @return A new IJasperReportTemplateDAO
	 */
    public IJasperReportTemplateDAO getJasperReportTemplateDAO();

    /**
     * Obtains a new DataSet for the JasperReportTemplate entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportTemplate> getJasperReportTemplateDataSet();

	/**
	 * Obtains a new JasperReportTemplateFile DAO
	 *
	 * @return A new IJasperReportTemplateFileDAO
	 */
    public IJasperReportTemplateFileDAO getJasperReportTemplateFileDAO();

    /**
     * Obtains a new DataSet for the JasperReportTemplateFile entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportTemplateFile> getJasperReportTemplateFileDataSet();

	/**
	 * Obtains a new JasperReportTemplateParam DAO
	 *
	 * @return A new IJasperReportTemplateParamDAO
	 */
    public IJasperReportTemplateParamDAO getJasperReportTemplateParamDAO();

    /**
     * Obtains a new DataSet for the JasperReportTemplateParam entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportTemplateParam> getJasperReportTemplateParamDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}

==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IReportManagerService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.ISqlDataSourceDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportTemplateDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportTemplateAreaDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportTemplateAreaTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportTemplateAreaSqlDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportInstanceDocumentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceDocument;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportInstanceDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstance;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportInstanceAreaDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceArea;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportInstanceAreaSqlDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IReportInstanceAreaTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IJasperReportConfigDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportConfig;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IJasperReportLogDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportLog;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IJasperReportTemplateDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IJasperReportTemplateFileDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateFile;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IJasperReportTemplateParamDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateParam;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IReportManagerService {

	/**
	 * Obtains a new SqlDataSource DAO
	 *
	 * @return A new ISqlDataSourceDAO
	 */
    public ISqlDataSourceDAO getSqlDataSourceDAO();

    /**
     * Obtains a new DataSet for the SqlDataSource entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<SqlDataSource> getSqlDataSourceDataSet();

	/**
	 * Obtains a new ReportTemplate DAO
	 *
	 * @return A new IReportTemplateDAO
	 */
    public IReportTemplateDAO getReportTemplateDAO();

    /**
     * Obtains a new DataSet for the ReportTemplate entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplate> getReportTemplateDataSet();

	/**
	 * Obtains a new ReportTemplateArea DAO
	 *
	 * @return A new IReportTemplateAreaDAO
	 */
    public IReportTemplateAreaDAO getReportTemplateAreaDAO();

    /**
     * Obtains a new DataSet for the ReportTemplateArea entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplateArea> getReportTemplateAreaDataSet();

	/**
	 * Obtains a new ReportTemplateAreaTrans DAO
	 *
	 * @return A new IReportTemplateAreaTransDAO
	 */
    public IReportTemplateAreaTransDAO getReportTemplateAreaTransDAO();

    /**
     * Obtains a new DataSet for the ReportTemplateAreaTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplateAreaTrans> getReportTemplateAreaTransDataSet();

	/**
	 * Obtains a new ReportTemplateAreaSql DAO
	 *
	 * @return A new IReportTemplateAreaSqlDAO
	 */
    public IReportTemplateAreaSqlDAO getReportTemplateAreaSqlDAO();

    /**
     * Obtains a new DataSet for the ReportTemplateAreaSql entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportTemplateAreaSql> getReportTemplateAreaSqlDataSet();

	/**
	 * Obtains a new ReportInstanceDocument DAO
	 *
	 * @return A new IReportInstanceDocumentDAO
	 */
    public IReportInstanceDocumentDAO getReportInstanceDocumentDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceDocument entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceDocument> getReportInstanceDocumentDataSet();

	/**
	 * Obtains a new ReportInstance DAO
	 *
	 * @return A new IReportInstanceDAO
	 */
    public IReportInstanceDAO getReportInstanceDAO();

    /**
     * Obtains a new DataSet for the ReportInstance entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstance> getReportInstanceDataSet();

	/**
	 * Obtains a new ReportInstanceArea DAO
	 *
	 * @return A new IReportInstanceAreaDAO
	 */
    public IReportInstanceAreaDAO getReportInstanceAreaDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceArea entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceArea> getReportInstanceAreaDataSet();

	/**
	 * Obtains a new ReportInstanceAreaSql DAO
	 *
	 * @return A new IReportInstanceAreaSqlDAO
	 */
    public IReportInstanceAreaSqlDAO getReportInstanceAreaSqlDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceAreaSql entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceAreaSql> getReportInstanceAreaSqlDataSet();

	/**
	 * Obtains a new ReportInstanceAreaTrans DAO
	 *
	 * @return A new IReportInstanceAreaTransDAO
	 */
    public IReportInstanceAreaTransDAO getReportInstanceAreaTransDAO();

    /**
     * Obtains a new DataSet for the ReportInstanceAreaTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<ReportInstanceAreaTrans> getReportInstanceAreaTransDataSet();

	/**
	 * Obtains a new JasperReportConfig DAO
	 *
	 * @return A new IJasperReportConfigDAO
	 */
    public IJasperReportConfigDAO getJasperReportConfigDAO();

    /**
     * Obtains a new DataSet for the JasperReportConfig entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportConfig> getJasperReportConfigDataSet();

	/**
	 * Obtains a new JasperReportLog DAO
	 *
	 * @return A new IJasperReportLogDAO
	 */
    public IJasperReportLogDAO getJasperReportLogDAO();

    /**
     * Obtains a new DataSet for the JasperReportLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportLog> getJasperReportLogDataSet();

	/**
	 * Obtains a new JasperReportTemplate DAO
	 *
	 * @return A new IJasperReportTemplateDAO
	 */
    public IJasperReportTemplateDAO getJasperReportTemplateDAO();

    /**
     * Obtains a new DataSet for the JasperReportTemplate entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportTemplate> getJasperReportTemplateDataSet();

	/**
	 * Obtains a new JasperReportTemplateFile DAO
	 *
	 * @return A new IJasperReportTemplateFileDAO
	 */
    public IJasperReportTemplateFileDAO getJasperReportTemplateFileDAO();

    /**
     * Obtains a new DataSet for the JasperReportTemplateFile entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportTemplateFile> getJasperReportTemplateFileDataSet();

	/**
	 * Obtains a new JasperReportTemplateParam DAO
	 *
	 * @return A new IJasperReportTemplateParamDAO
	 */
    public IJasperReportTemplateParamDAO getJasperReportTemplateParamDAO();

    /**
     * Obtains a new DataSet for the JasperReportTemplateParam entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<JasperReportTemplateParam> getJasperReportTemplateParamDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}
